@@ -160,7 +160,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.726");
+    setStatus("Using qgvdial version 0.2.728");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -543,8 +543,6 @@ MainWindow::init ()
 void
 MainWindow::initQML ()
 {
-    onDesktopResized ();
-
     qmlRegisterType<WebWidget>("org.qgvdial.WebWidget", 1, 0, "MyWebWidget");
 
     bool bTempFalse = false;
@@ -563,7 +561,14 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
 
     // Initialize the QML view
+#if defined(MEEGO_HARMATTAN)
+    this->setSource (QUrl ("qrc:/HMain.qml"));
+#else
     this->setSource (QUrl ("qrc:/Main.qml"));
+#endif
+
+    onDesktopResized ();
+
 #if 0 && defined(MEEGO_HARMATTAN)
     // Do rotate
     QMetaObject::invokeMethod (this->rootObject(), "doRotate",
@@ -576,7 +581,12 @@ MainWindow::initQML ()
     this->setPassword ("hunter2 :p");
 
     // The root object changes when we reload the source. Pick it up again.
-    QGraphicsObject *gObj = this->rootObject();
+    QObject *gObj = this->getMainPage();
+    if (NULL == gObj) {
+        qWarning ("Could not get to MainPage");
+        qApp->quit();
+        return;
+    }
 
     bool bOk;
     // Connect all signals to slots in this class.
@@ -1401,8 +1411,7 @@ MainWindow::gotAllRegisteredPhones (bool bOk, const QVariantList &params)
     Q_ASSERT(rv); Q_UNUSED(rv);
 
     do { // Begin cleanup block (not a loop)
-        if (!bOk)
-        {
+        if (!bOk) {
             this->showMsgBox ("Failed to retrieve registered phones");
             setStatus ("Failed to retrieve registered phones");
             break;
@@ -1451,10 +1460,8 @@ MainWindow::retrieveVoicemail (const QString &strVmailLink)
 {
     GVAccess &webPage = Singletons::getRef().getGVAccess ();
 
-    do // Begin cleanup block (not a loop)
-    {
-        if (mapVmail.contains (strVmailLink))
-        {
+    do { // Begin cleanup block (not a loop)
+        if (mapVmail.contains (strVmailLink)) {
             setStatus ("Playing cached vmail");
             playVmail (mapVmail[strVmailLink]);
             break;
@@ -1464,8 +1471,7 @@ MainWindow::retrieveVoicemail (const QString &strVmailLink)
                             + QDir::separator ()
                             + "qgv_XXXXXX.tmp.mp3";
         QTemporaryFile tempFile (strTemplate);
-        if (!tempFile.open ())
-        {
+        if (!tempFile.open ()) {
             qWarning ("Failed to get a temp file name");
             break;
         }
@@ -1488,8 +1494,7 @@ void
 MainWindow::onVmailDownloaded (bool bOk, const QVariantList &arrParams)
 {
     QString strFilename = arrParams[1].toString ();
-    if (bOk)
-    {
+    if (bOk) {
         QString strVmailLink = arrParams[0].toString ();
         if (!mapVmail.contains (strVmailLink))
         {
@@ -1505,9 +1510,7 @@ MainWindow::onVmailDownloaded (bool bOk, const QVariantList &arrParams)
         }
 
         playVmail (mapVmail[strVmailLink]);
-    }
-    else
-    {
+    } else {
         QFile::remove (strFilename);
     }
 }//MainWindow::onVmailDownloaded
@@ -1515,8 +1518,7 @@ MainWindow::onVmailDownloaded (bool bOk, const QVariantList &arrParams)
 void
 MainWindow::playVmail (const QString &strFile)
 {
-    do // Begin cleanup block (not a loop)
-    {
+    do { // Begin cleanup block (not a loop)
         // Convert it into a file:// url
         QUrl url = QUrl::fromLocalFile(strFile).toString ();
 
@@ -1868,6 +1870,7 @@ MainWindow::refreshPinSettings()
                                    Q_ARG (QVariant, QVariant(strPin)));
     } while (0); // End cleanup block (not a loop)
 }//MainWindow::refreshPinSettings
+
 void
 MainWindow::showMsgBox (const QString &strMessage)
 {
@@ -2124,7 +2127,41 @@ MainWindow::onDesktopResized()
     OsDependent &osd = Singletons::getRef().getOSD ();
     QRect rect = osd.getStartingSize (this);
 
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_MainWidth", rect.width ());
-    ctx->setContextProperty ("g_MainHeight", rect.height ());
+    do { // Begin cleanup block (not a loop)
+        QObject *pMain = this->rootObject ();
+        if (NULL == pMain) {
+            qWarning ("Could not get to MainPage for resize");
+            break;
+        }
+
+        pMain->setProperty("height", rect.height());
+        pMain->setProperty("width", rect.width());
+    } while (0); // End cleanup block (not a loop)
 }//MainWindow::onDesktopResized
+
+QObject *
+MainWindow::getMainPage()
+{
+    QObject *pMain = NULL;
+    do { // Begin cleanup block (not a loop)
+        QObject *pRoot = this->rootObject ();
+        if (NULL == pRoot) {
+            qWarning ("Couldn't get root object in QML for MainPage");
+            break;
+        }
+
+        if (pRoot->objectName() == "MainPage") {
+            pMain = pRoot;
+            break;
+        }
+
+        pMain = pRoot->findChild <QObject*> ("MainPage");
+        if (NULL == pMain) {
+            qWarning ("Could not get to MainPage");
+            break;
+        }
+    } while (0); // End cleanup block (not a loop)
+
+    return (pMain);
+}//MainWindow::getMainPage
+
